@@ -1,6 +1,8 @@
-from typing import Any, List
+import dataclasses
+from typing import Any, List, Type
 
 from strawberry.experimental.pydantic.exceptions import UnregisteredTypeException
+from strawberry.private import is_private
 from strawberry.utils.typing import (
     get_list_annotation,
     get_optional_annotation,
@@ -24,3 +26,13 @@ def get_strawberry_type_from_model(type_: Any):
         return type_._strawberry_type
     else:
         raise UnregisteredTypeException(type_)
+
+
+def get_private_fields(cls: Type) -> List[dataclasses.Field]:
+    private_fields: List[dataclasses.Field] = []
+
+    for field in dataclasses.fields(cls):
+        if is_private(field.type):
+            private_fields.append(field)
+
+    return private_fields
